@@ -2,5 +2,5 @@ from elixir import *
 
 class B(Entity):
     name = Field(String(30))
-    as_ = OneToMany('tests.a.A')
+    many_a = OneToMany('tests.a.A')
 
