@@ -1,10 +1,10 @@
 from elixir import *
 from elixir.ext.encrypted import acts_as_encrypted
- 
+
 
 def setup():
     global Person, Pet
-    
+
     class Person(Entity):
         name = Field(String(50))
         password = Field(String(40))
@@ -18,8 +18,9 @@ def setup():
         acts_as_encrypted(for_fields=['codename'], with_secret='secret2')
         owner = ManyToOne('Person')
 
-    
-    metadata.bind = 'sqlite:///'
+
+    metadata.bind = 'sqlite://'
+    setup_all()
 
 
 def teardown():
@@ -28,17 +29,17 @@ def teardown():
 
 class TestEncryption(object):
     def setup(self):
-        setup_all(True)
-    
+        create_all()
+
     def teardown(self):
         drop_all()
-        session.clear()
-    
-    def test_encryption(self):    
+        session.close()
+
+    def test_encryption(self):
         jonathan = Person(
-            name=u'Jonathan LaCour', 
-            password=u's3cr3tw0RD', 
-            ssn=u'123-45-6789'
+            name='Jonathan LaCour',
+            password='s3cr3tw0RD',
+            ssn='123-45-6789'
         )
         winston = Pet(
             name='Winston',
@@ -50,7 +51,8 @@ class TestEncryption(object):
         )
         jonathan.pets = [winston, nelson]
 
-        session.flush(); session.clear()
+        session.commit()
+        session.clear()
 
         p = Person.get_by(name='Jonathan LaCour')
         assert p.password == 's3cr3tw0RD'
@@ -62,10 +64,37 @@ class TestEncryption(object):
 
         p.password = 'N3wpAzzw0rd'
 
-        session.flush(); session.clear()
+        session.commit()
+        session.clear()
 
         p = Person.get_by(name='Jonathan LaCour')
         assert p.password == 'N3wpAzzw0rd'
-        p.name = 'Jon LaCour'
 
-        session.flush(); session.clear()
+    def test_two_consecutive_updates(self):
+        jonathan = Person(
+            name='Jonathan LaCour',
+            password='s3cr3tw0RD',
+            ssn='123-45-6789'
+        )
+        session.commit()
+        session.clear()
+
+        p = Person.get_by(name='Jonathan LaCour')
+        assert p.password == 's3cr3tw0RD'
+        p.name = 'JONATHAN LACOUR'
+        session.flush()
+
+        assert p.password == 'r\\x9d\\xa8\\xb4\\x8d|\\xffp\\xf5\\x0e'
+
+        p.name = 'Jonathan LaCour'
+        session.flush()
+
+        # check that it is not further encrypted
+        assert p.password == 'r\\x9d\\xa8\\xb4\\x8d|\\xffp\\xf5\\x0e'
+
+        session.commit()
+        session.clear()
+
+        p = Person.get_by(name='Jonathan LaCour')
+        assert p.password == 's3cr3tw0RD'
+
