@@ -7,9 +7,9 @@ from elixir import *
 
 def setup():
     global Record, Artist, Genre
-    
+
     class Record(Entity):
-        title = Field(Unicode(100))
+        title = Field(String(100))
         year = Field(Integer)
         artist = ManyToOne('Artist')
         genres = ManyToMany('Genre')
@@ -21,14 +21,14 @@ def setup():
             return "%s - %s (%d)" % (self.artist.name, self.title, self.year)
 
     class Artist(Entity):
-        name = Field(Unicode(30))
+        name = Field(String(30))
         records = OneToMany('Record', order_by=['year', '-title'])
 
     class Genre(Entity):
-        name = Field(Unicode(30))
+        name = Field(String(30))
         records = ManyToMany('Record', order_by='-title')
 
-    metadata.bind = 'sqlite:///'
+    metadata.bind = 'sqlite://'
     setup_all(True)
 
     # insert some data
@@ -42,15 +42,15 @@ def setup():
         ("Metropolis Pt. 2: Scenes From A Memory", 1999),
         ("Octavarium", 2005),
         # 2005 is a mistake to make the test more interesting
-        ("Six Degrees Of Inner Turbulence", 2005), 
+        ("Six Degrees Of Inner Turbulence", 2005),
         ("Train Of Thought", 2003),
         ("When Dream And Day Unite", 1989)
     )
-    
+
     for title, year in titles:
         Record(title=title, artist=artist, year=year, genres=[genre])
 
-    session.flush()
+    session.commit()
     session.clear()
 
 
@@ -61,14 +61,10 @@ def teardown():
 class TestOrderBy(object):
     def teardown(self):
         session.clear()
-    
+
     def test_mapper_order_by(self):
         records = Record.query.all()
 
-        print "-year, +title"
-        for record in records:
-            print record
-
         assert records[0].year == 2005
         assert records[2].year >= records[5].year
         assert records[3].year >= records[4].year
@@ -77,10 +73,6 @@ class TestOrderBy(object):
     def test_o2m_order_by(self):
         records = Artist.get_by(name="Dream Theater").records
 
-        print "+year, -title"
-        for record in records:
-            print record
-
         assert records[0].year == 1989
         assert records[2].year <= records[5].year
         assert records[3].year <= records[4].year
@@ -90,10 +82,6 @@ class TestOrderBy(object):
     def test_m2m_order_by(self):
         records = Genre.get_by(name="Progressive metal").records
 
-        print "-title"
-        for record in records:
-            print record
-
         assert records[0].year == 1989
         assert records[2].title >= records[5].title
         assert records[3].title >= records[4].title
