@@ -7,19 +7,29 @@ from sqlalchemy.orm import column_property
 from elixir import *
 
 def setup():
-    metadata.bind = 'sqlite:///'
+    metadata.bind = 'sqlite://'
 
 
 class TestSpecialProperties(object):
     def teardown(self):
         cleanup_all(True)
-    
+
+    def test_lifecycle(self):
+        class A(Entity):
+            name = Field(String(20))
+
+        assert isinstance(A.name, Field)
+
+        setup_all()
+
+        assert not isinstance(A.name, Field)
+
     def test_generic_property(self):
         class Tag(Entity):
             score1 = Field(Float)
             score2 = Field(Float)
 
-            score = GenericProperty( 
+            score = GenericProperty(
                          lambda c: column_property(
                              (c.score1 * c.score2).label('score')))
         setup_all(True)
@@ -27,9 +37,9 @@ class TestSpecialProperties(object):
         t1 = Tag(score1=5.0, score2=3.0)
         t2 = Tag(score1=10.0, score2=2.0)
 
-        session.flush()
+        session.commit()
         session.clear()
-        
+
         for tag in Tag.query.all():
             assert tag.score == tag.score1 * tag.score2
 
@@ -45,9 +55,9 @@ class TestSpecialProperties(object):
         t1 = Tag(score1=5.0, score2=3.0)
         t2 = Tag(score1=10.0, score2=2.0)
 
-        session.flush()
+        session.commit()
         session.clear()
-        
+
         for tag in Tag.query.all():
             assert tag.score == tag.score1 * tag.score2
 
@@ -55,43 +65,43 @@ class TestSpecialProperties(object):
         class Tag(Entity):
             score1 = Field(Float)
             score2 = Field(Float)
- 
+
             user = ManyToOne('User')
- 
+
             score = ColumnProperty(lambda c: c.score1 * c.score2)
- 
+
         class User(Entity):
             name = Field(String(16))
             category = ManyToOne('Category')
             tags = OneToMany('Tag', lazy=False)
-            score = ColumnProperty(lambda c: 
+            score = ColumnProperty(lambda c:
                                    select([func.sum(Tag.score)],
                                           Tag.user_id == c.id).as_scalar())
- 
+
         class Category(Entity):
             name = Field(String(16))
-            users = OneToMany('User', lazy=False) 
- 
-            score = ColumnProperty(lambda c: 
-                                   select([func.sum(User.score)],
+            users = OneToMany('User', lazy=False)
+
+            score = ColumnProperty(lambda c:
+                                   select([func.avg(User.score)],
                                           User.category_id == c.id
                                          ).as_scalar())
         setup_all(True)
- 
-        u1 = User(name='joe', tags=[Tag(score1=5.0, score2=3.0), 
+
+        u1 = User(name='joe', tags=[Tag(score1=5.0, score2=3.0),
                                     Tag(score1=55.0, score2=1.0)])
- 
-        u2 = User(name='bar', tags=[Tag(score1=5.0, score2=4.0), 
+
+        u2 = User(name='bar', tags=[Tag(score1=5.0, score2=4.0),
                                     Tag(score1=50.0, score2=1.0),
                                     Tag(score1=15.0, score2=2.0)])
- 
+
         c1 = Category(name='dummy', users=[u1, u2])
 
-        session.flush()
+        session.commit()
         session.clear()
 
         category = Category.query.one()
-#        assert category.score == 85 # doesn't work for now
+        assert category.score == 85
         for user in category.users:
             assert user.score == sum([tag.score for tag in user.tags])
             for tag in user.tags:
@@ -101,7 +111,7 @@ class TestSpecialProperties(object):
         class Tag(Entity):
             has_field('score1', Float)
             has_field('score2', Float)
-            has_property('score', 
+            has_property('score',
                          lambda c: column_property(
                              (c.score1 * c.score2).label('score')))
 
@@ -110,9 +120,9 @@ class TestSpecialProperties(object):
         t1 = Tag(score1=5.0, score2=3.0)
         t1 = Tag(score1=10.0, score2=2.0)
 
-        session.flush()
+        session.commit()
         session.clear()
-        
+
         for tag in Tag.query.all():
             assert tag.score == tag.score1 * tag.score2
 
@@ -124,7 +134,7 @@ class TestSpecialProperties(object):
         setup_all(True)
 
         A(name='foo')
-        session.flush()
+        session.commit()
 
     def test_synonym(self):
         class Person(Entity):
@@ -154,11 +164,12 @@ class TestSpecialProperties(object):
 
         assert Person.email_values == ['x@y.com', 'x@z.com']
 
-        session.flush()
+        session.commit()
         session.clear()
-       
+
+        # test the synonym itself (ie querying)
         p = Person.get_by(email='x@z.com')
-        
+
         assert p.name == 'Mr. X'
 
     def test_synonym_class(self):
@@ -183,7 +194,7 @@ class TestSpecialProperties(object):
             password = 'unencrypted'
         )
 
-        session.flush(); session.clear()
+        session.commit(); session.clear()
 
         p = Person.get_by(name='Alexandre da Silva')
         assert p.primary_email == 'x@y.com'
@@ -192,8 +203,24 @@ class TestSpecialProperties(object):
         assert u.email_address == 'y@z.com'
 
         u.email_address = 'new@z.com'
-        session.flush(); session.clear()
+        session.commit(); session.clear()
 
         p = Person.get_by(name='Johann Felipe Voigt')
         assert p.primary_email == 'new@z.com'
 
+    def test_setattr(self):
+        class A(Entity):
+            pass
+
+        A.name = Field(String(30))
+
+        setup_all(True)
+
+        a1 = A(name='a1')
+
+        session.commit(); session.clear()
+
+        a = A.query.one()
+
+        assert a.name == 'a1'
+
